==> istio-model-v1alpha3-6.4.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/ConnectionPoolSettingsFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ConnectionPoolSettingsFluentImpl<A extends ConnectionPoolSettingsFluent<A>> extends BaseFluent<A> implements ConnectionPoolSettingsFluent<A>{
  public ConnectionPoolSettingsFluentImpl() {
  }
  public ConnectionPoolSettingsFluentImpl(ConnectionPoolSettings instance) {
    this.withHttp(instance.getHttp()); 
    this.withTcp(instance.getTcp()); 
  }
  private ConnectionPoolSettingsHTTPSettingsBuilder http;
  private ConnectionPoolSettingsTCPSettingsBuilder tcp;
  
  /**
   * This method has been deprecated, please use method buildHttp instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConnectionPoolSettingsHTTPSettings getHttp() {
    return this.http!=null ?this.http.build():null;
  }
  public ConnectionPoolSettingsHTTPSettings buildHttp() {
    return this.http!=null ?this.http.build():null;
  }
  public A withHttp(ConnectionPoolSettingsHTTPSettings http) {
    _visitables.get("http").remove(this.http);
    if (http!=null){ this.http= new ConnectionPoolSettingsHTTPSettingsBuilder(http); _visitables.get("http").add(this.http);} else { this.http = null; _visitables.get("http").remove(this.http); } return (A) this;
  }
  public Boolean hasHttp() {
    return this.http != null;
  }
  public ConnectionPoolSettingsFluent.HttpNested<A> withNewHttp() {
    return new ConnectionPoolSettingsFluentImpl.HttpNestedImpl();
  }
  public ConnectionPoolSettingsFluent.HttpNested<A> withNewHttpLike(ConnectionPoolSettingsHTTPSettings item) {
    return new ConnectionPoolSettingsFluentImpl.HttpNestedImpl(item);
  }
  public ConnectionPoolSettingsFluent.HttpNested<A> editHttp() {
    return withNewHttpLike(getHttp());
  }
  public ConnectionPoolSettingsFluent.HttpNested<A> editOrNewHttp() {
    return withNewHttpLike(getHttp() != null ? getHttp(): new ConnectionPoolSettingsHTTPSettingsBuilder().build());
  }
  public ConnectionPoolSettingsFluent.HttpNested<A> editOrNewHttpLike(ConnectionPoolSettingsHTTPSettings item) {
    return withNewHttpLike(getHttp() != null ? getHttp(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildTcp instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConnectionPoolSettingsTCPSettings getTcp() {
    return this.tcp!=null ?this.tcp.build():null;
  }
  public ConnectionPoolSettingsTCPSettings buildTcp() {
    return this.tcp!=null ?this.tcp.build():null;
  }
  public A withTcp(ConnectionPoolSettingsTCPSettings tcp) {
    _visitables.get("tcp").remove(this.tcp);
    if (tcp!=null){ this.tcp= new ConnectionPoolSettingsTCPSettingsBuilder(tcp); _visitables.get("tcp").add(this.tcp);} else { this.tcp = null; _visitables.get("tcp").remove(this.tcp); } return (A) this;
  }
  public Boolean hasTcp() {
    return this.tcp != null;
  }
  public ConnectionPoolSettingsFluent.TcpNested<A> withNewTcp() {
    return new ConnectionPoolSettingsFluentImpl.TcpNestedImpl();
  }
  public ConnectionPoolSettingsFluent.TcpNested<A> withNewTcpLike(ConnectionPoolSettingsTCPSettings item) {
    return new ConnectionPoolSettingsFluentImpl.TcpNestedImpl(item);
  }
  public ConnectionPoolSettingsFluent.TcpNested<A> editTcp() {
    return withNewTcpLike(getTcp());
  }
  public ConnectionPoolSettingsFluent.TcpNested<A> editOrNewTcp() {
    return withNewTcpLike(getTcp() != null ? getTcp(): new ConnectionPoolSettingsTCPSettingsBuilder().build());
  }
  public ConnectionPoolSettingsFluent.TcpNested<A> editOrNewTcpLike(ConnectionPoolSettingsTCPSettings item) {
    return withNewTcpLike(getTcp() != null ? getTcp(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConnectionPoolSettingsFluentImpl that = (ConnectionPoolSettingsFluentImpl) o;
    if (http != null ? !http.equals(that.http) :that.http != null) return false;
    if (tcp != null ? !tcp.equals(that.tcp) :that.tcp != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(http,  tcp,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (http != null) { sb.append("http:"); sb.append(http + ","); }
    if (tcp != null) { sb.append("tcp:"); sb.append(tcp); }
    sb.append("}");
    return sb.toString();
  }
  class HttpNestedImpl<N> extends ConnectionPoolSettingsHTTPSettingsFluentImpl<ConnectionPoolSettingsFluent.HttpNested<N>> implements ConnectionPoolSettingsFluent.HttpNested<N>,Nested<N>{
    HttpNestedImpl(ConnectionPoolSettingsHTTPSettings item) {
      this.builder = new ConnectionPoolSettingsHTTPSettingsBuilder(this, item);
    }
    HttpNestedImpl() {
      this.builder = new ConnectionPoolSettingsHTTPSettingsBuilder(this);
    }
    ConnectionPoolSettingsHTTPSettingsBuilder builder;
    public N and() {
      return (N) ConnectionPoolSettingsFluentImpl.this.withHttp(builder.build());
    }
    public N endHttp() {
      return and();
    }
    
  }
  class TcpNestedImpl<N> extends ConnectionPoolSettingsTCPSettingsFluentImpl<ConnectionPoolSettingsFluent.TcpNested<N>> implements ConnectionPoolSettingsFluent.TcpNested<N>,Nested<N>{
    TcpNestedImpl(ConnectionPoolSettingsTCPSettings item) {
      this.builder = new ConnectionPoolSettingsTCPSettingsBuilder(this, item);
    }
    TcpNestedImpl() {
      this.builder = new ConnectionPoolSettingsTCPSettingsBuilder(this);
    }
    ConnectionPoolSettingsTCPSettingsBuilder builder;
    public N and() {
      return (N) ConnectionPoolSettingsFluentImpl.this.withTcp(builder.build());
    }
    public N endTcp() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/ConnectionPoolSettingsFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ConnectionPoolSettingsFluentImpl<A extends ConnectionPoolSettingsFluent<A>> extends BaseFluent<A> implements ConnectionPoolSettingsFluent<A>{
  public ConnectionPoolSettingsFluentImpl() {
  }
  public ConnectionPoolSettingsFluentImpl(ConnectionPoolSettings instance) {
    if (instance != null) {
      this.withHttp(instance.getHttp());
      this.withTcp(instance.getTcp());
    }
  }
  private ConnectionPoolSettingsHTTPSettingsBuilder http;
  private ConnectionPoolSettingsTCPSettingsBuilder tcp;
  
  /**
   * This method has been deprecated, please use method buildHttp instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConnectionPoolSettingsHTTPSettings getHttp() {
    return this.http!=null ?this.http.build():null;
  }
  public ConnectionPoolSettingsHTTPSettings buildHttp() {
    return this.http!=null ?this.http.build():null;
  }
  public A withHttp(ConnectionPoolSettingsHTTPSettings http) {
    _visitables.get("http").remove(this.http);
    if (http!=null){ this.http= new ConnectionPoolSettingsHTTPSettingsBuilder(http); _visitables.get("http").add(this.http);} else { this.http = null; _visitables.get("http").remove(this.http); } return (A) this;
  }
  public Boolean hasHttp() {
    return this.http != null;
  }
  public ConnectionPoolSettingsFluentImpl.HttpNested<A> withNewHttp() {
    return new ConnectionPoolSettingsFluentImpl.HttpNestedImpl();
  }
  public ConnectionPoolSettingsFluentImpl.HttpNested<A> withNewHttpLike(ConnectionPoolSettingsHTTPSettings item) {
    return new ConnectionPoolSettingsFluentImpl.HttpNestedImpl(item);
  }
  public ConnectionPoolSettingsFluentImpl.HttpNested<A> editHttp() {
    return withNewHttpLike(getHttp());
  }
  public ConnectionPoolSettingsFluentImpl.HttpNested<A> editOrNewHttp() {
    return withNewHttpLike(getHttp() != null ? getHttp(): new ConnectionPoolSettingsHTTPSettingsBuilder().build());
  }
  public ConnectionPoolSettingsFluentImpl.HttpNested<A> editOrNewHttpLike(ConnectionPoolSettingsHTTPSettings item) {
    return withNewHttpLike(getHttp() != null ? getHttp(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildTcp instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConnectionPoolSettingsTCPSettings getTcp() {
    return this.tcp!=null ?this.tcp.build():null;
  }
  public ConnectionPoolSettingsTCPSettings buildTcp() {
    return this.tcp!=null ?this.tcp.build():null;
  }
  public A withTcp(ConnectionPoolSettingsTCPSettings tcp) {
    _visitables.get("tcp").remove(this.tcp);
    if (tcp!=null){ this.tcp= new ConnectionPoolSettingsTCPSettingsBuilder(tcp); _visitables.get("tcp").add(this.tcp);} else { this.tcp = null; _visitables.get("tcp").remove(this.tcp); } return (A) this;
  }
  public Boolean hasTcp() {
    return this.tcp != null;
  }
  public ConnectionPoolSettingsFluentImpl.TcpNested<A> withNewTcp() {
    return new ConnectionPoolSettingsFluentImpl.TcpNestedImpl();
  }
  public ConnectionPoolSettingsFluentImpl.TcpNested<A> withNewTcpLike(ConnectionPoolSettingsTCPSettings item) {
    return new ConnectionPoolSettingsFluentImpl.TcpNestedImpl(item);
  }
  public ConnectionPoolSettingsFluentImpl.TcpNested<A> editTcp() {
    return withNewTcpLike(getTcp());
  }
  public ConnectionPoolSettingsFluentImpl.TcpNested<A> editOrNewTcp() {
    return withNewTcpLike(getTcp() != null ? getTcp(): new ConnectionPoolSettingsTCPSettingsBuilder().build());
  }
  public ConnectionPoolSettingsFluentImpl.TcpNested<A> editOrNewTcpLike(ConnectionPoolSettingsTCPSettings item) {
    return withNewTcpLike(getTcp() != null ? getTcp(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConnectionPoolSettingsFluentImpl that = (ConnectionPoolSettingsFluentImpl) o;
    if (!java.util.Objects.equals(http, that.http)) return false;

    if (!java.util.Objects.equals(tcp, that.tcp)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(http,  tcp,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (http != null) { sb.append("http:"); sb.append(http + ","); }
    if (tcp != null) { sb.append("tcp:"); sb.append(tcp); }
    sb.append("}");
    return sb.toString();
  }
  class HttpNestedImpl<N> extends ConnectionPoolSettingsHTTPSettingsFluentImpl<ConnectionPoolSettingsFluentImpl.HttpNested<N>> implements ConnectionPoolSettingsFluentImpl.HttpNested<N>,Nested<N>{
    HttpNestedImpl(ConnectionPoolSettingsHTTPSettings item) {
      this.builder = new ConnectionPoolSettingsHTTPSettingsBuilder(this, item);
    }
    HttpNestedImpl() {
      this.builder = new ConnectionPoolSettingsHTTPSettingsBuilder(this);
    }
    ConnectionPoolSettingsHTTPSettingsBuilder builder;
    public N and() {
      return (N) ConnectionPoolSettingsFluentImpl.this.withHttp(builder.build());
    }
    public N endHttp() {
      return and();
    }
    
  }
  class TcpNestedImpl<N> extends ConnectionPoolSettingsTCPSettingsFluentImpl<ConnectionPoolSettingsFluentImpl.TcpNested<N>> implements ConnectionPoolSettingsFluentImpl.TcpNested<N>,Nested<N>{
    TcpNestedImpl(ConnectionPoolSettingsTCPSettings item) {
      this.builder = new ConnectionPoolSettingsTCPSettingsBuilder(this, item);
    }
    TcpNestedImpl() {
      this.builder = new ConnectionPoolSettingsTCPSettingsBuilder(this);
    }
    ConnectionPoolSettingsTCPSettingsBuilder builder;
    public N and() {
      return (N) ConnectionPoolSettingsFluentImpl.this.withTcp(builder.build());
    }
    public N endTcp() {
      return and();
    }
    
  }
  
}
